; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
;
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
;
;
; This script copies the visible layers contained within the active
; image and pastes the results into a single layer at the top of the stack
; of the active image  It is an updated version of Karl Ward's merge-copy script
; which can be found here: http://kward1979uk.deviantart.com/art/Merge-copy-28607825
;
; The Script can be found in the Image's Edit Menu under the name: "Copy Visible & Paste"
;
; Special thanks to saulgoode at gimptalk.com for his suggestions on improving the script.

; Define the Function
(define
 (copy-paste-new-layer
  inImage
  inDraw)

 ; Declare the Variables
 (let*
  ((theHeight (car (gimp-image-height inImage)))
   (theWidth (car (gimp-image-width inImage)))
   (theFloatingSelection -1)
   (theType (car (gimp-drawable-type-with-alpha inDraw))) ; returns the drawable's type with an Alpha Channel
   (selectionWidth -1)
   (selectionHeight -1)
   (theSelection 42)
   (theResult 42)
   (theOpacity (car (gimp-layer-get-opacity inDraw))) ; for layer opacity
  )

  ; Begin Undo Group
  (gimp-image-undo-group-start inImage)

  ; Copy the selection from the current layer
  (gimp-edit-copy inDraw)

  (let*
    ((ss (gimp-selection-bounds inImage))
    ;; item 0 is #t if we have a selection
    ;; todo: if it is #f, bail out of the script with an error
    ;; (or, select all?)
    ;;
    ;; next items are x1 y1 x2 y2
     (x1 (list-ref ss 1))
     (y1 (list-ref ss 2))
     (x2 (list-ref ss 3))
     (y2 (list-ref ss 4)))

    (set! selectionWidth (- x2 x1))
    (set! selectionHeight (- y2 y1))

    ; Get the selected area in the image and save it to a channel
    (set! theSelection (car (gimp-selection-save inImage)))

    ; Create a new layer called "Copied Layer" to hold the pasted selection
    (set! theResult (car (gimp-layer-new inImage selectionWidth selectionHeight theType "복사된 레이어" theOpacity NORMAL-MODE)))

    ; move the layer into position
    (gimp-layer-set-offsets theResult x1 y1)


  ; Fills theResult Layer (aka Copied Layer) with transparent fill
  (gimp-drawable-fill theResult TRANSPARENT-FILL)

  ; Adds theResult Layer to the active image
  (gimp-image-add-layer inImage theResult 0)

  ; Defines theFloatingSelection variable as containing the pasted layer and keeping the selection active
  (set! theFloatingSelection (car (gimp-edit-paste theResult FALSE)))

  ; Anchor theFloatingSelection to theResult
  (gimp-floating-sel-anchor theFloatingSelection)

  ; Reload the original selection (theSelection)
  (gimp-selection-load theSelection)

  ; Delete the channel holding the original selection (theSelection)
  (gimp-image-remove-channel inImage theSelection))

  ; End Undo Group
  (gimp-image-undo-group-end inImage))

  ; Update display
  (gimp-displays-flush))

(script-fu-register  "copy-paste-new-layer"
               "<Image>/Edit/Copy/선택을 새 레이어로.."
               "선택을 복사하여 현재 이미지의 새 레이어로 붙여넣습니다."
               "Art Wade"
               "Art Wade"
               "December 2007"
               ""
               SF-IMAGE      "SF-IMAGE" 0
               SF-DRAWABLE   "SF-DRAWABLE" 0

)

